@@ -20,6 +20,10 @@ mainwindow::mainwindow(QWidget *parent) :
         ui->zoomonpress->setDisabled(true);
     }
 
+    if (!QFile::exists("/opt/cssutransitionstuner/tactileinstalled")) {
+        ui->tactile->setDisabled(true);
+    }
+
     readvalues();
 }
 
@@ -402,9 +406,17 @@ void mainwindow::on_pushButton_clicked()
     //QMaemo5InformationBox::information(this, tr("Transitions updated!") +  "<br /><br />" + tr("Some changes requires restarting the device to activate them."), QMaemo5InformationBox::NoTimeout);
 
     QMessageBox msgBox;
-    msgBox.setWindowTitle("CSSU Transitions tuner");
+    msgBox.setWindowTitle("CSSU Transitions Tuner");
     msgBox.setText("Transitions updated! <br /><br />Reboot is required to activate all changes.");
     msgBox.exec();
 
     ui->pushButton->setEnabled(true);
 }
+
+void mainwindow::on_pushButton_2_clicked()
+{
+    QMessageBox msgBox;
+    msgBox.setWindowTitle("CSSU Transitions Tuner");
+    msgBox.setText("CSSU Transitions Tuner ver. 0.0.3<br /><br />Auhtor: d-iivil<br />Licence: GPL");
+    msgBox.exec();
+}
